@@ -13,7 +13,7 @@ sys.path = [os.path.join(root, '..')] + sys.path
 from notable import bottle, db, editor
 
 # Constants, and help with template lookup
-version = '0.0.1'
+version = '0.0.2a'
 static = os.path.join(root, 'static')
 bottle.TEMPLATE_PATH.insert(0, os.path.join(root, 'views'))
 
@@ -32,6 +32,12 @@ def decrypt():
     uid = bottle.request.forms.get('uid')
     return db.get_content(uid, password)
 
+@bottle.post('/api/delete')
+def delete():
+    password = bottle.request.forms.get('password')
+    uid = bottle.request.forms.get('uid')
+    return dict(success=db.delete_note(uid, password=password))
+
 @bottle.post('/api/launch_editor')
 def launch_editor():
     uid = bottle.request.forms.get('uid')
